/************************************************************************

sample.c - generate sample data

This file is a part of sscsss -- Simple Single Cycle Sample Set Synthesizer.

Copyright (C) 2002 David Baker

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

************************************************************************/

#include <math.h>

#include "s1m.h"
#include "sscsss.h"

#define PI 3.14159265358979323846

void gen_sample(S_P s, double sample[], double *max_absv)
{
    double inc;
    int i;
    H_P hp;

    /* initialize */
    inc = 2.0 * PI * ( s->freq / S1M_SR ); /* phase increment 1st harmonic */
    *max_absv = 0.0;

    /* for each sample point */
    for ( i = 0; i < s->smpl_len; i++ ) {
	sample[i] = 0.0;

	/* loop through harmonic list */
	for ( hp = s->h_list; hp != NULL; hp = hp->next) {
	    sample[i] += pow(10, hp->level / 20) * /* amplitude (from dba) */
			 sin(i * inc * hp->no +	   /* frequency */
			  hp->phase * 2.0 * PI);   /* phase */
	}

	/* save max absolute value for peak normalization */
	if ( fabs(sample[i]) > *max_absv ) *max_absv = fabs(sample[i]);
    }
}

/* end of sample.c */

