#
#	test.sh	- sscsss regression tests
#

# malloc errors not generated

#####
### setup
#####

cd ~/sscsss/test
rm -f sscsss init.s1m
cp ../sscsss ../init.s1m .

#####
### input validation
#####

#	main - sscsss.c

echo
sh tst00101.sh		# not enough command line arguments
sh tst00102.sh		# too many command line arguments
sh tst00103.sh		# cannot open input file
sh tst00104.sh		# cannot open output file
# successfully opening correct output file (.s1m) implicitly checked below
echo

#	get_input - input.c

#	get_opts_fname - input.c

sh tst00301.sh		# eof looking for file
sh tst00302.sh		# file not first
sh tst00303.sh		# eof looking for option or voice, no options
sh tst00304.sh		# expecting 1st option or voice
sh tst00305.sh		# eof looking for option or voice, after one option
sh tst00306.sh		# expecting 2nd or later option or voice
echo

#	file_proc - input.c

sh tst00401.sh		# no filename arg to file
sh tst00402.sh		# too many args to file
sh tst00403.sh		# file name too long
sh tst00404.sh		# file name cannot be init
sh tst00405.sh		# cannot open log file
# successfully opening correct log file implicitly checked by below
echo

#	option_proc - input.c

sh tst00501.sh		# option must have at least one argument
sh tst00502.sh		# option lowfreq - not enough args
sh tst00503.sh		# option lowfreq - too many args
sh tst00504.sh		# option lowfreq - lowfreq not a number
sh tst00505.sh		# option lowfreq - lowfreq must be >= 0.01
sh tst00506.sh		# option lowfreq - lowfreq must be <= 8
sh tst00507.sh		# option mindba - not enough args
sh tst00508.sh		# option mindba - too many args
sh tst00509.sh		# option mindba - mindba not a number
sh tst00510.sh		# option mindba - mindba must be <= -40
sh tst00511.sh		# option debug - has no additional arguments
sh tst00512.sh		# option logws - has no additional arguments
sh tst00513.sh		# option mkplot - has no additional arguments
sh tst00514.sh		# option plotlog - has no additional arguments
sh tst00515.sh		# option plotpause - has no additional arguments
# 516 517 deleted due to program change
sh tst00518.sh		# unknown option
# check successful setting of options later
echo

#	get_voice - input.c

sh tst00601.sh		# eof while looking for set or wave
sh tst00602.sh		# expecting set or wave
sh tst00603.sh		# eof while looking for offset, filter, formant,
			#   or split
sh tst00604.sh		# expecting scale, offset, filter, formant or split
# 0605 - 0608 deleted due to program change
sh tst00609.sh		# after offset eof while looking for offset, scale,
			#  filter formant, or split
sh tst00610.sh		# after offset expecting offset, scale,
			#  filter formant, or split
sh tst00611.sh		# after offset scale eof while looking for point
sh tst00612.sh		# after offset scale expecting point
sh tst00613.sh		# after offset scale point eof while looking for point
			#   scale, offset, filter, formant, or split
sh tst00614.sh		# after offset scale point expecting point
			#   scale, offset, filter, formant, or split
sh tst00615.sh		# after filter eof while looking for filter, scale,
			#   gpoint, formant, or split
sh tst00616.sh		# after filter expecting filter, scale, gpoint
			#   formant, or split
sh tst00617.sh		# after filter scale eof while looking for point
sh tst00618.sh		# after filter scale expecting point
sh tst00619.sh		# after filter scale point eof while looking for point,
			#   filter, formant, or split
sh tst00620.sh		# after filter scale point expecting point,
			#   filter, formant, or split

# added later for graph point
sh tst00640.sh		# after filter eof while looking for gpoint, filter,
			#   formant, or split
sh tst00641.sh		# after filter expecting gpoint, filter, formant,
			#   or split

sh tst00621.sh		# after formant eof while looking for formant, gpoint,
			#   or split
sh tst00622.sh		# after formant expecting formant, gpoint, or split

# added later for graph point
sh tst00642.sh		# after formant eof while looking for gpoint, formant,
			#   or split
sh tst00643.sh		# after formant expecting gpoint, formant, or split

sh tst00623.sh		# after split eof while looking for note or condition
sh tst00624.sh		# after split expecting note or condition
sh tst00625.sh		# after note eof while looking for note or condition
sh tst00626.sh		# after note expecting note or condition
sh tst00627.sh		# after split condition expecting condition, split,
			#   wave, set, voice, or end of file

sh tst00628.sh		# after wave eof while looking for sample
sh tst00629.sh		# after wave expecting sample
sh tst00630.sh		# after sample eof while looking for harmonic
sh tst00631.sh		# after sample expecting harmonic
sh tst00632.sh		# after harmonic expecting harmonic, sample, wave,
			#   voice, or end of file
echo

#	voice_proc - input.c

sh tst00701.sh		# too few arguments
sh tst00702.sh		# too many arguments
sh tst00703.sh		# name too long
sh tst00704.sh		# unknown Category
sh tst00705.sh		# bend is not a number
sh tst00706.sh		# bend < 0
sh tst00707.sh		# bend > 127
sh tst00708.sh		# must specify both low and high
sh tst00709.sh		# low bad number
sh tst00710.sh		# low < 0
sh tst00711.sh		# low > 127
sh tst00712.sh		# high bad number
sh tst00713.sh		# high < 0
sh tst00714.sh		# high > 127
sh tst00715.sh		# low > high
sh tst00716.sh		# Normalization type must be sample or voice
echo

#	set_proc - input.c

sh tst00801.sh		# voice high/low notes needed for defining wave sets
# 0802, 0804 - 0810 deleted due to program change
sh tst00803.sh		# too many arguments
echo

#	offset_proc - input.c

sh tst00901.sh		# too few arguments
sh tst00902.sh		# too many arguments
sh tst00903.sh		# Harmonic bad number
sh tst00904.sh		# Harmonic must be >= 1
sh tst00905.sh		# Level bad number
sh tst00906.sh		# Level must be between -90 and 90
sh tst00907.sh		# Level must be between -90 and 90
sh tst00908.sh		# Phase bad number
sh tst00909.sh		# Phase must be >= 0.0 and < 1.0
sh tst00910.sh		# Phase must be >= 0.0 and < 1.0
echo

#	filter_proc - input.c

sh tst01001.sh		# too few arguments
sh tst01002.sh		# Unknown filter type
sh tst01003.sh		# P1, bad number
sh tst01004.sh		# P1 not between 0.0 and 10.0
sh tst01005.sh		# P1 not between 0.0 and 10.0

# added later for graph point
sh tst01030.sh		# after filter (graph) too many arguments for this type

sh tst01006.sh		# P2 bad number
sh tst01007.sh		# cos (etc.) P2 not between -90.0 and 90.0
sh tst01008.sh		# cos (etc.) P2 not between -90.0 and 90.0
sh tst01009.sh		# highpass (etc.) P2 may not be 0.0
sh tst01010.sh		# band P2 not between 0.0 and 10.0
sh tst01011.sh		# band P2 not between 0.0 and 10.0

# too many args (end of p2, possible?)

sh tst01012.sh		# cos incorrect number of arguments (start of p3)
sh tst01013.sh		# cos P3 bad number
sh tst01014.sh		# cos (etc.) P3 not between 0.0 and 10.0
sh tst01015.sh		# cos (etc.) P3 not between 0.0 and 10.0
sh tst01016.sh		# highshelf (etc.) P3 may not be 0.0
sh tst01017.sh		# band P3 not between -90.0 and 90.0
sh tst01018.sh		# band P3 not between -90.0 and 90.0
sh tst01019.sh		# highpass too many arguments for this type
sh tst01020.sh		# band incorrect number of arguments
sh tst01021.sh		# band P4 bad number
sh tst01022.sh		# band P4 may not be 0.0
sh tst01023.sh		# cos too many arguments for this type

sh tst01024.sh		# highshelf p2 and p3 have different signs
echo

#	scale_proc - input.c

# added later
sh tst01120.sh		# Cannot scale filter type graph

sh tst01101.sh		# too few arguments
sh tst01102.sh		# too many arguments
# 01103 01104 deleted due to program change
sh tst01105.sh		# Level for this offset already scaled
sh tst01106.sh		# Phase for this offset already scaled
sh tst01107.sh		# Can only scale level or phase for an offset
sh tst01108.sh		# P1 for this filter already scaled
sh tst01109.sh		# P2 for this filter already scaled
sh tst01110.sh		# No p3 for this filter type
sh tst01111.sh		# P3 for this filter already scaled
sh tst01112.sh		# No p4 for this filter type
sh tst01113.sh		# P4 for this filter already scaled
sh tst01114.sh		# Can only scale p1, p2, p3, p4 for a filter
echo

#	point_proc - input.c

sh tst01201.sh		# too few arguments
sh tst01202.sh		# too many arguments
sh tst01203.sh		# Frequency bad number
sh tst01204.sh		# Frequency must be increasing
sh tst01205.sh		# Value bad number
# 01206 deleted due to program change
sh tst01207.sh		# offset level must be between -90 and 90
sh tst01208.sh		# offset level must be between -90 and 90
sh tst01209.sh		# offset phase must be >= than 0.0 and < 1.0
sh tst01210.sh		# offset phase must be >= than 0.0 and < 1.0
sh tst01211.sh		# filter P1 must be between 0 and 10
sh tst01212.sh		# filter P1 must be between 0 and 10
sh tst01213.sh		# filter cos (etc.) P2 must be between -90 and 90
sh tst01214.sh		# filter cos (etc.) P2 must be between -90 and 90
sh tst01215.sh		# filter high pass (etc.) P2 may not be 0.0
sh tst01216.sh		# filter band P2 not between 0.0 and 10.0
sh tst01217.sh		# filter band P2 not between 0.0 and 10.0
sh tst01218.sh		# filter cos (etc.) P3 must be > 0 and <= 10
sh tst01219.sh		# filter cos (etc.) P3 must be > 0 and <= 10
sh tst01220.sh		# filter low shelf (etc.) P3 may not be 0.0
sh tst01221.sh		# filter band P3 must be between -90.0 and 90.0
sh tst01222.sh		# filter band P3 must be between -90.0 and 90.0
sh tst01223.sh		# filter band P4 may not be 0.0
echo

#	gpoint_proc - input.c - added later for graph point
sh tst02101.sh		# gpoint only allowed for graph filter/formant
sh tst02102.sh		# Incorrect number of arguments
sh tst02103.sh		# Incorrect number of arguments
sh tst02104.sh		# Frequency bad number
sh tst02105.sh		# Frequency (octave) not between 0 and 11
sh tst02106.sh		# Frequency (octave) not between 0 and 11
sh tst02107.sh		# Frequency not between 0 and 40000
sh tst02108.sh		# Frequency not between 0 and 40000
sh tst02109.sh		# Gain bad number
sh tst02110.sh		# Gain not between -90 and 90
sh tst02111.sh		# Gain not between -90 and 90
sh tst02112.sh		# Frequencies must be increasing
echo

#	formant_proc - input.c

sh tst01301.sh		# Incorrect number of arguments
sh tst01302.sh		# Unknown formant type
sh tst01303.sh		# P1 bad number
sh tst01304.sh		# P1 not between 1.0 and 20,000.0
sh tst01305.sh		# P1 not between 1.0 and 20,000.0

# added
sh tst01330.sh		# Too many arguments for this type

sh tst01306.sh		# P2 bad number
sh tst01307.sh		# cos (etc.) P2 not between -90.0 and 90.0
sh tst01308.sh		# cos (etc.) P2 not between -90.0 and 90.0
sh tst01309.sh		# highpass (etc.) P2 may not be 0.0
sh tst01310.sh		# band P2 not between 1.0 and 20,000.0
sh tst01311.sh		# band P2 not between 1.0 and 20,000.0
sh tst01312.sh		# band P1 must be <= P2

# too many arguments (end of p2, possible?)

sh tst01313.sh		# cos (etc.) Incorrect number of arguments
sh tst01314.sh		# P3 bad number
sh tst01315.sh		# cos (etc.) P3 not between 0.0 and 10.0
sh tst01316.sh		# cos (etc.) P3 not between 0.0 and 10.0
sh tst01317.sh		# lowshelf (etc.) P3 may not be 0.0
sh tst01318.sh		# band P3 must be between -90.0 and 90.0
sh tst01319.sh		# band P3 must be between -90.0 and 90.0
sh tst01320.sh		# low pass (etc.) Too many arguments for this type
sh tst01321.sh		# band Incorrect number of arguments
sh tst01322.sh		# band P4 bad number
sh tst01323.sh		# band P4 may not be 0.0
sh tst01324.sh		# cos (etc.) Too many arguments for this type

sh tst01325.sh		# lowshelf p2 and p3 have different signs
echo

#	split_proc - input.c

sh tst01401.sh		# Too few arguments
sh tst01402.sh		# Notes bad number
sh tst01403.sh		# Notes must be between 1 and 128
sh tst01404.sh		# Notes must be between 1 and 128
sh tst01405.sh		# Too many arguments
echo

#	note_proc - input.c

sh tst01501.sh		# Incorrect number of arguments
sh tst01502.sh		# Incorrect number of arguments
sh tst01503.sh		# Center bad number
sh tst01504.sh		# Low bad number
sh tst01505.sh		# High bad number
sh tst01506.sh		# Must have 0 <= low <= center <= high <= 127
sh tst01507.sh		# Must have current low = previous high + 1
echo

#	condition_proc - input.c

sh tst01601.sh		# Too few arguments
sh tst01602.sh		# Too many arguments
sh tst01603.sh		# Operator must be one of
			#   =, <, <=, >, >=, %, not, and, or
sh tst01604.sh		# > (etc.) Expecting frequency
sh tst01605.sh		# > (etc.) Frequency bad number
sh tst01606.sh		# > (etc.) Frequency must be between 1.0 and 20000.0
sh tst01607.sh		# > (etc.) Frequency must be between 1.0 and 20000.0
sh tst01608.sh		# > (etc.) Harmonic bad number
sh tst01609.sh		# > (etc.) Harmonic must be >= 0
sh tst01610.sh		# % Incorrect number of arguments
sh tst01611.sh		# % Divisor bad number
sh tst01612.sh		# % Divisor must be greater than 1
sh tst01613.sh		# % Remainder bad number
sh tst01614.sh		# % Remainder must be 0 to 1 less than divisor
sh tst01615.sh		# % Remainder must be 0 to 1 less than divisor
sh tst01616.sh		# or (etc.) Incorrect number of arguments
echo

#	wave_proc - input.c

sh tst01701.sh		# Incorrect number of arguments
sh tst01702.sh		# Too many waves in voice
sh tst01703.sh		# Too many waves in file
echo

#	sample_proc - input.c

sh tst01801.sh		# Too few arguments
sh tst01802.sh		# Too many arguments
sh tst01803.sh		# Too many samples in wave
sh tst01804.sh		# Too many samples in file
sh tst01805.sh		# Center bad number
sh tst01806.sh		# Center must be >= 0 and <= 127
sh tst01807.sh		# Center must be >= 0 and <= 127
sh tst01808.sh		# Low bad number
sh tst01809.sh		# Low must be >= 0 and <= center
sh tst01810.sh		# Low must be >= 0 and <= center
sh tst01811.sh		# High bad number
sh tst01812.sh		# High must be >= center and <= 127
sh tst01813.sh		# High must be >= center and <= 127
sh tst01814.sh		# Frequency bad number
sh tst01815.sh		# Frequency out of range
sh tst01816.sh		# Frequency out of range
echo

#	harmonic_proc - input.c

sh tst01901.sh		# Incorrect number of argument
sh tst01902.sh		# Incorrect number of argument
sh tst01903.sh		# Harmonic bad number
sh tst01904.sh		# Number must > 0 and increasing
sh tst01905.sh		# Number must > 0 and increasing
sh tst01906.sh		# Level bad number
sh tst01907.sh		# Level must be between -90.0 and 0.0 (dba)
sh tst01908.sh		# Level must be between -90.0 and 0.0 (dba)
sh tst01909.sh		# Phase bad number
sh tst01910.sh		# Phase must be >= 0.0 and < 1.0
sh tst01911.sh		# Phase must be >= 0.0 and < 1.0
echo

#	waveset.c

sh tst02001.sh		# Sample with no harmonics
sh tst02002.sh		# Too many waves in voice
sh tst02003.sh		# Too many waves in file
# 02004 - 02006 deleted due to program change

# fix me - too many samples in wave - possible ?

sh tst02007.sh		# Too many samples in file
sh tst02008.sh		# Condition list finished with more than 1 operand
			#   on stack
sh tst02009.sh		# Stack overflow
sh tst02010.sh		# Stack underflow
#sh tst02011.sh		# Empty stack - can this happen?
sh tst02012.sh		# Freq1 > freq2 in band filter, scaling?

sh tst02013.sh		# p2 p3 different signs in high shelf filter, scaling?
sh tst02014.sh		# p2 p3 different signs in low shelf filter, scaling?

sh tst02015.sh		# Notes = 'list' and no note list, nothing to generate

echo

#####
### calculations
#####

sh calctstx.sh

#####
### cleanup
#####

rm -f tst*.in
rm -f tst*.out
rm -f tst*.log
rm -f tst*.s1m
rm -f tst*.plt

rm -f calctst*.log
rm -f calctst*.s1m
rm -f ct*.plt

rm -f sscsss
rm -f init.s1m

# end of test.sh

